@@ -21,14 +21,14 @@
 #ifndef PLUGIN_H
 #define PLUGIN_H
 
-#include <QtQml/QQmlExtensionPlugin>
+#include <QQmlExtensionPlugin>
 
 class Plugin : public QQmlExtensionPlugin
 {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 public:
-    virtual void registerTypes(const char * uri);
+    void registerTypes(const char * uri) override;
 };
 
 #endif // PLUGIN_H
